CategoryFilter class

Matches logs whose TraceKeys.category is in categories.

Implemented types

Constructors

CategoryFilter(Set<String> categories)
const

Properties

categories Set<String>
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

apply(ISpectLogData item) bool
Returns true if the item matches the filter condition.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited