KeyBasedRedaction class

Redacts values based on key names: fully-masked keys and sensitive keys.

Fully-masked keys always produce RedactionContext.placeholder regardless of whether the key is also classified as sensitive. Sensitive keys get partial masking (edge-visible) for strings and placeholder for other types.

Implemented types

Constructors

KeyBasedRedaction()
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
tryRedact(Object? node, {required RedactionContext context, String? keyName}) Object?
override

Operators

operator ==(Object other) bool
The equality operator.
inherited