NetworkLogPrintOptions class abstract interface

Abstraction describing print preferences and color configuration for network-related logs.

Packages implementing request/response/error interceptors should expose a settings object that implements this interface so shared network log builders can produce consistent output.

Implementers

Properties

errorPen AnsiPen?
Optional pen to override the default error log color.
no setter
hashCode int
The hash code for this object.
no setterinherited
printErrorData bool
Whether error payloads should be printed in the log message.
no setter
printErrorHeaders bool
Whether error headers should be printed in the log message.
no setter
printErrorMessage bool
Whether the error status/message should be printed in the log summary.
no setter
printRequestData bool
Whether request bodies should be printed in the log message.
no setter
printRequestHeaders bool
Whether request headers should be printed in the log message.
no setter
printResponseData bool
Whether response payloads should be printed in the log message.
no setter
printResponseHeaders bool
Whether response headers should be printed in the log message.
no setter
printResponseMessage bool
Whether the response status message should be printed.
no setter
requestPen AnsiPen?
Optional pen to override the default request log color.
no setter
responsePen AnsiPen?
Optional pen to override the default response log color.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited