Top-level keys in ISpectLogData.additionalData for trace envelope.
Not to be confused with NetworkJsonKeys — those are used INSIDE meta
for domain payload.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- category → const String
- correlationId → const String
- durationMs → const String
- error → const String
- key → const String
- meta → const String
- operation → const String
- slow → const String
- source → const String
- success → const String
- target → const String
- transactionId → const String
- value → const String