ISpectLogDataX extension
Convenience getters for accessing structured trace data in ISpectLogData.
All getters use defensive is checks instead of as casts.
If additionalData contains unexpected types (v4 logs, custom data,
deserialized JSON), getters safely return null instead of throwing.
Properties
- authProvider → String?
-
Available on ISpectLogData, provided by the ISpectLogDataX extension
no setter - blocType → String?
-
Available on ISpectLogData, provided by the ISpectLogDataX extension
no setter -
dbArgs
→ List<
Object?> ? -
Available on ISpectLogData, provided by the ISpectLogDataX extension
no setter - dbStatement → String?
-
Available on ISpectLogData, provided by the ISpectLogDataX extension
no setter - dbStatementDigest → String?
-
Available on ISpectLogData, provided by the ISpectLogDataX extension
no setter - eventType → String?
-
Available on ISpectLogData, provided by the ISpectLogDataX extension
no setter -
httpHeaders
→ Map<
String, dynamic> ? -
Available on ISpectLogData, provided by the ISpectLogDataX extension
no setter - httpStatusCode → int?
-
Available on ISpectLogData, provided by the ISpectLogDataX extension
no setter - isAnalytics → bool
-
Available on ISpectLogData, provided by the ISpectLogDataX extension
no setter - isAuth → bool
-
Available on ISpectLogData, provided by the ISpectLogDataX extension
no setter - isDb → bool
-
Available on ISpectLogData, provided by the ISpectLogDataX extension
no setter - isGraphql → bool
-
Available on ISpectLogData, provided by the ISpectLogDataX extension
no setter - isGrpc → bool
-
Available on ISpectLogData, provided by the ISpectLogDataX extension
no setter -
Available on ISpectLogData, provided by the ISpectLogDataX extension
no setter - isNetwork → bool
-
Available on ISpectLogData, provided by the ISpectLogDataX extension
no setter - isPayment → bool
-
Available on ISpectLogData, provided by the ISpectLogDataX extension
no setter - isPush → bool
-
Available on ISpectLogData, provided by the ISpectLogDataX extension
no setter - isSse → bool
-
Available on ISpectLogData, provided by the ISpectLogDataX extension
no setter - isState → bool
-
Available on ISpectLogData, provided by the ISpectLogDataX extension
no setter - isStorage → bool
-
Available on ISpectLogData, provided by the ISpectLogDataX extension
no setter - isWs → bool
-
Available on ISpectLogData, provided by the ISpectLogDataX extension
no setter - paymentAmount → double?
-
Available on ISpectLogData, provided by the ISpectLogDataX extension
NB:numcheck — JSON may return int (100) instead of double (100.0).no setter - paymentCurrency → String?
-
Available on ISpectLogData, provided by the ISpectLogDataX extension
no setter - pushTitle → String?
-
Available on ISpectLogData, provided by the ISpectLogDataX extension
no setter - pushTopic → String?
-
Available on ISpectLogData, provided by the ISpectLogDataX extension
no setter - requestId → String?
-
Available on ISpectLogData, provided by the ISpectLogDataX extension
no setter - storageBucket → String?
-
Available on ISpectLogData, provided by the ISpectLogDataX extension
no setter - storageSizeBytes → int?
-
Available on ISpectLogData, provided by the ISpectLogDataX extension
no setter - traceCategory → String?
-
Available on ISpectLogData, provided by the ISpectLogDataX extension
no setter - traceCorrelationId → String?
-
Available on ISpectLogData, provided by the ISpectLogDataX extension
no setter - traceDurationMs → int?
-
Available on ISpectLogData, provided by the ISpectLogDataX extension
no setter -
traceMeta
→ Map<
String, dynamic> ? -
Available on ISpectLogData, provided by the ISpectLogDataX extension
no setter - traceOperation → String?
-
Available on ISpectLogData, provided by the ISpectLogDataX extension
no setter - traceSlow → bool?
-
Available on ISpectLogData, provided by the ISpectLogDataX extension
no setter - traceSource → String?
-
Available on ISpectLogData, provided by the ISpectLogDataX extension
no setter - traceSuccess → bool?
-
Available on ISpectLogData, provided by the ISpectLogDataX extension
no setter - traceTarget → String?
-
Available on ISpectLogData, provided by the ISpectLogDataX extension
no setter - traceTransactionId → String?
-
Available on ISpectLogData, provided by the ISpectLogDataX extension
no setter
Methods
-
hasCategory(
String categoryId) → bool -
Available on ISpectLogData, provided by the ISpectLogDataX extension
Check any custom category:log.hasCategory('my-service')