NetworkFilter<T> class
abstract
Base class for network filter chain units.
A filter decides whether a network event (request, response, or error) should be logged. Filters are synchronous, stateless by convention, and side-effect free.
Implement apply to return true when the event should be logged.
- Implementers
Constructors
- NetworkFilter()
-
const
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
apply(
T value) → bool -
Returns
trueifvalueshould be logged. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited